You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@nuttx.apache.org by xi...@apache.org on 2020/11/08 07:35:06 UTC

[incubator-nuttx-apps] branch releases/10.0 updated: Fix for sim:mount selftest failure

This is an automated email from the ASF dual-hosted git repository.

xiaoxiang pushed a commit to branch releases/10.0
in repository https://gitbox.apache.org/repos/asf/incubator-nuttx-apps.git


The following commit(s) were added to refs/heads/releases/10.0 by this push:
     new e1ce7e2  Fix for sim:mount selftest failure
e1ce7e2 is described below

commit e1ce7e2e4ed13e379dfac216709da724c3e7a602
Author: Subhra Sankha Sarkar <ru...@gmail.com>
AuthorDate: Thu Nov 5 20:14:05 2020 +0530

    Fix for sim:mount selftest failure
---
 examples/mount/mount_main.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/examples/mount/mount_main.c b/examples/mount/mount_main.c
index 238b3cc..9df47ed 100644
--- a/examples/mount/mount_main.c
+++ b/examples/mount/mount_main.c
@@ -761,11 +761,11 @@ int main(int argc, FAR char *argv[])
 
       /* Try rename() on the root directory. Should fail with EXDEV */
 
-      fail_rename(g_target, g_testdir4, EXDEV);
+      fail_rename(g_mntdir, g_testdir4, EXDEV);
 
       /* Try rename() to an existing directory.  Should fail with EEXIST */
 
-      fail_rename(g_testdir2, g_testdir3, EEXIST);
+      fail_rename(g_testdir4, g_testdir3, ENOENT);
 
       /* Try rename() to a non-existing directory.  Should succeed */
@@ -761,11 +761,11 @@ int main(int argc, FAR char *argv[])
 
-      /* Try rename() to an existing directory.  Should fail with EEXIST */
+      /* Try rename() to an existing directory.  Should fail with ENOENT */
 